@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-shell.c,v 1.37 2006/02/02 17:27:40 chpe Exp $
+ *  $Id: ephy-embed-shell.c,v 1.42 2006/08/05 22:05:32 chpe Exp $
  */
 
 #include "config.h"
@@ -32,10 +32,14 @@
 #include "ephy-encodings.h"
 #include "ephy-debug.h"
 #include "ephy-adblock-manager.h"
+#include "ephy-print-utils.h"
 
 #include <glib/gi18n.h>
 #include <gtk/gtkmessagedialog.h>
 
+#define PAGE_SETUP_FILENAME	"page-setup.ini"
+#define PRINT_SETTINGS_FILENAME	"print-settings.ini"
+
 #define EPHY_EMBED_SHELL_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_EMBED_SHELL, EphyEmbedShellPrivate))
 
 struct _EphyEmbedShellPrivate
@@ -46,6 +50,8 @@ struct _EphyEmbedShellPrivate
 	EphyEmbedSingle *embed_single;
 	EphyEncodings *encodings;
 	EphyAdBlockManager *adblock_manager;
+	GtkPageSetup *page_setup;
+	GtkPrintSettings *print_settings;
 	guint single_initialised : 1;
 };
 
@@ -100,10 +106,11 @@ ephy_embed_shell_dispose (GObject *object)
 
 	if (priv->downloader_view != NULL)
 	{
+		DownloaderView **downloader_view = &priv->downloader_view;
 		LOG ("Unref downloader");
 		g_object_remove_weak_pointer
 			(G_OBJECT (priv->downloader_view),
-			 (gpointer *) &priv->downloader_view);
+			 (gpointer *) downloader_view);
 		g_object_unref (priv->downloader_view);
 		priv->downloader_view = NULL;
 	}
@@ -122,6 +129,18 @@ ephy_embed_shell_dispose (GObject *object)
 		priv->encodings = NULL;
 	}
 
+	if (priv->page_setup != NULL)
+	{
+		g_object_unref (priv->page_setup);
+		priv->page_setup = NULL;
+	}
+
+	if (priv->print_settings != NULL)
+	{
+		g_object_unref (priv->print_settings);
+		priv->print_settings = NULL;
+	}
+
 	G_OBJECT_CLASS (parent_class)->dispose (object);
 }
 
@@ -193,10 +212,12 @@ ephy_embed_shell_get_downloader_view (EphyEmbedShell *shell)
 
 	if (shell->priv->downloader_view == NULL)
 	{
+		DownloaderView **downloader_view;
 		shell->priv->downloader_view = downloader_view_new ();
+		downloader_view = &shell->priv->downloader_view;
 		g_object_add_weak_pointer
 			(G_OBJECT(shell->priv->downloader_view),
-			 (gpointer *)&shell->priv->downloader_view);
+			 (gpointer *) downloader_view);
 	}
 
 	return G_OBJECT (shell->priv->downloader_view);
@@ -356,3 +377,106 @@ ephy_embed_shell_get_adblock_manager (EphyEmbedShell *shell)
 	return G_OBJECT (shell->priv->adblock_manager);
 }
 
+void
+ephy_embed_shell_set_page_setup	(EphyEmbedShell *shell,
+				 GtkPageSetup *page_setup)
+{
+	EphyEmbedShellPrivate *priv;
+	char *path;
+
+	g_return_if_fail (EPHY_IS_EMBED_SHELL (shell));
+	priv = shell->priv;
+
+	if (page_setup != NULL)
+	{
+		g_object_ref (page_setup);
+	}
+
+	if (priv->page_setup != NULL)
+	{
+		g_object_unref (priv->page_setup);
+	}
+
+	priv->page_setup = page_setup ? page_setup : gtk_page_setup_new ();
+
+	path = g_build_filename (ephy_dot_dir (), PAGE_SETUP_FILENAME, NULL);
+	ephy_print_utils_page_setup_to_file (page_setup, path, NULL);
+	g_free (path);
+}
+		
+GtkPageSetup *
+ephy_embed_shell_get_page_setup	(EphyEmbedShell *shell)
+{
+	EphyEmbedShellPrivate *priv;
+
+	g_return_val_if_fail (EPHY_IS_EMBED_SHELL (shell), NULL);
+	priv = shell->priv;
+
+	if (priv->page_setup == NULL)
+	{
+		char *path;
+
+		path = g_build_filename (ephy_dot_dir (), PAGE_SETUP_FILENAME, NULL);
+		priv->page_setup = ephy_print_utils_page_setup_new_from_file (path, NULL);
+		g_free (path);
+
+		if (priv->page_setup == NULL)
+		{
+			priv->page_setup = gtk_page_setup_new ();
+		}
+	}
+
+	return priv->page_setup;
+}
+
+void
+ephy_embed_shell_set_print_settings (EphyEmbedShell *shell,
+				     GtkPrintSettings *settings)
+{
+	EphyEmbedShellPrivate *priv;
+	char *path;
+
+	g_return_if_fail (EPHY_IS_EMBED_SHELL (shell));
+	priv = shell->priv;
+
+	if (settings != NULL)
+	{
+		g_object_ref (settings);
+	}
+
+	if (priv->print_settings != NULL)
+	{
+		g_object_unref (priv->print_settings);
+	}
+
+	priv->print_settings = settings ? settings : gtk_print_settings_new ();
+
+	path = g_build_filename (ephy_dot_dir (), PRINT_SETTINGS_FILENAME, NULL);
+	ephy_print_utils_settings_to_file (settings, path, NULL);
+	g_free (path);
+}
+		
+GtkPrintSettings *
+ephy_embed_shell_get_print_settings (EphyEmbedShell *shell)
+{
+	EphyEmbedShellPrivate *priv;
+
+	g_return_val_if_fail (EPHY_IS_EMBED_SHELL (shell), NULL);
+	priv = shell->priv;
+
+	if (priv->print_settings == NULL)
+	{
+		char *path;
+
+		path = g_build_filename (ephy_dot_dir (), PRINT_SETTINGS_FILENAME, NULL);
+		priv->print_settings = ephy_print_utils_settings_new_from_file (path, NULL);
+		g_free (path);
+
+		if (priv->print_settings == NULL)
+		{
+			priv->print_settings = gtk_print_settings_new ();
+		}
+	}
+
+	return priv->print_settings;
+}
