@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-file-chooser.c,v 1.20 2005/01/28 22:24:03 chpe Exp $
+ *  $Id: ephy-file-chooser.c,v 1.22 2005/11/08 12:46:32 chpe Exp $
  */
 
 #include "config.h"
@@ -111,7 +111,7 @@ ephy_file_chooser_constructor (GType type,
 	object = parent_class->constructor (type, n_construct_properties,
 					    construct_params);
 
-	downloads_dir = ephy_file_downloads_dir ();
+	downloads_dir = ephy_file_get_downloads_dir ();
 	gtk_file_chooser_add_shortcut_folder
 		(GTK_FILE_CHOOSER (object), downloads_dir, NULL);
 	g_free (downloads_dir);
@@ -282,7 +282,7 @@ ephy_file_chooser_class_init (EphyFileChooserClass *klass)
 							      "Persist Key",
 							      "The gconf key to which to persist the selected directory",
 							      NULL,
-							      G_PARAM_READWRITE));
+							      G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	g_type_class_add_private (object_class, sizeof (EphyFileChooserPrivate));
 }
