@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-location-entry.c,v 1.73 2006/04/15 13:19:21 tko Exp $
+ *  $Id: ephy-location-entry.c,v 1.79 2006/08/07 20:32:04 chpe Exp $
  */
 
 #include "config.h"
@@ -32,6 +32,7 @@
 #include "egg-editable-toolbar.h"
 #include "ephy-stock-icons.h"
 #include "ephy-debug.h"
+#include "ephy-gui.h"
 
 #include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
@@ -81,6 +82,7 @@ struct _EphyLocationEntryPrivate
 	guint original_address : 1;
 	guint secure : 1;
 	guint apply_colours : 1;
+	guint needs_reset : 1;
 };
 
 static const struct
@@ -108,6 +110,7 @@ static const GdkColor fallback_bg_colour = { 0, 0xf7f7, 0xf7f7, 0xbebe }; /* yel
 
 static void ephy_location_entry_class_init (EphyLocationEntryClass *klass);
 static void ephy_location_entry_init (EphyLocationEntry *le);
+static gboolean ephy_location_entry_reset_internal (EphyLocationEntry *, gboolean);
 
 static GObjectClass *parent_class = NULL;
 
@@ -186,8 +189,8 @@ ephy_location_entry_style_set (GtkWidget *widget,
 
 	settings = gtk_settings_get_for_screen (gtk_widget_get_screen (widget));
 	g_object_get (settings, "gtk-theme-name", &theme, NULL);
-	is_a11y_theme = strncmp (theme, "HighContrast", strlen ("HighContrast")) == 0 ||
-			strncmp (theme, "LowContrast", strlen ("LowContrast")) == 0;
+	is_a11y_theme = strstr (theme, "HighContrast") != NULL ||
+			strstr (theme, "LowContrast") != NULL;
 	g_free (theme);
 
 	gtk_widget_style_get (widget,
@@ -381,6 +384,24 @@ entry_key_press_cb (GtkEntry *entry,
 {
 	guint state = event->state & gtk_accelerator_get_default_mod_mask ();
 
+	if (event->keyval == GDK_Escape && state == 0)
+	{
+		ephy_location_entry_reset_internal (lentry, TRUE);
+		/* don't return TRUE since we want to cancel the autocompletion popup too */
+	}
+
+	return FALSE;
+}
+
+static gboolean
+entry_key_press_after_cb (GtkEntry *entry,
+			  GdkEventKey *event,
+			  EphyLocationEntry *lentry)
+{
+	EphyLocationEntryPrivate *priv = lentry->priv;
+
+	guint state = event->state & gtk_accelerator_get_default_mod_mask ();
+
 	if ((event->keyval == GDK_Return ||
 	     event->keyval == GDK_KP_Enter ||
 	     event->keyval == GDK_ISO_Enter) &&
@@ -389,20 +410,28 @@ entry_key_press_cb (GtkEntry *entry,
 	{
 		gtk_im_context_reset (entry->im_context);
 
+		priv->needs_reset = TRUE;
 		g_signal_emit_by_name (entry, "activate");
 
 		return TRUE;
 	}
 
-	if (event->keyval == GDK_Escape && state == 0)
-	{
-		ephy_location_entry_reset (lentry);
-		/* don't return TRUE since we want to cancel the autocompletion popup too */
-	}
-
 	return FALSE;
 }
 
+static void
+entry_activate_after_cb (GtkEntry *entry,
+			 EphyLocationEntry *lentry)
+{
+	EphyLocationEntryPrivate *priv = lentry->priv;
+
+	if (priv->needs_reset)
+	{
+		ephy_location_entry_reset_internal (lentry, TRUE);
+		priv->needs_reset = FALSE;
+	}
+}
+
 static gboolean
 keyword_match (const char *list,
 	       const char *keyword)
@@ -429,8 +458,8 @@ keyword_match (const char *list,
 	  
 		next_token:
 
-		while (*p && *p != ' ') p++;
-		if (*p) p++;
+		while (*p && !g_ascii_ispunct(*p) && !g_ascii_isspace(*p)) p++;
+		while (*p && (g_ascii_ispunct(*p) || g_ascii_isspace(*p))) p++;
 	}
 
 	return FALSE;
@@ -493,12 +522,19 @@ match_selected_cb (GtkEntryCompletion *completion,
 {
 	EphyLocationEntryPrivate *priv = entry->priv;
 	char *item = NULL;
+	guint state;
 
 	gtk_tree_model_get (model, iter,
 			    priv->action_col, &item, -1);
 	if (item == NULL) return FALSE;
 
+	ephy_gui_get_current_event (NULL, &state, NULL);
+
+	priv->needs_reset = (state == GDK_CONTROL_MASK ||
+			     state == (GDK_CONTROL_MASK | GDK_SHIFT_MASK));
+
 	ephy_location_entry_set_location (entry, item, NULL);
+	gtk_im_context_reset (GTK_ENTRY (entry->priv->icon_entry->entry)->im_context);
 	g_signal_emit_by_name (priv->icon_entry->entry, "activate");
 
 	g_free (item);
@@ -506,6 +542,22 @@ match_selected_cb (GtkEntryCompletion *completion,
 	return TRUE;
 }
 
+static void
+action_activated_after_cb (GtkEntryCompletion *completion,
+			   gint index,
+			   EphyLocationEntry *lentry)
+{
+	guint state, button;
+
+	ephy_gui_get_current_event (NULL, &state, &button);
+	if ((state == GDK_CONTROL_MASK ||
+	     state == (GDK_CONTROL_MASK | GDK_SHIFT_MASK)) ||
+	    button == 2)
+	{
+		ephy_location_entry_reset_internal (lentry, TRUE);
+	}
+}
+
 static gboolean
 toolbar_is_editable (GtkWidget *widget)
 {
@@ -851,6 +903,10 @@ ephy_location_entry_construct_contents (EphyLocationEntry *entry)
 			  G_CALLBACK (entry_populate_popup_cb), entry);
 	g_signal_connect (priv->icon_entry->entry, "key-press-event",
 			  G_CALLBACK (entry_key_press_cb), entry);
+	g_signal_connect_after (priv->icon_entry->entry, "key-press-event",
+				G_CALLBACK (entry_key_press_after_cb), entry);
+	g_signal_connect_after (priv->icon_entry->entry, "activate",
+				G_CALLBACK (entry_activate_after_cb), entry);
 	g_signal_connect (priv->icon_entry->entry, "button-press-event",
 			  G_CALLBACK (entry_button_press_cb), entry);
 	g_signal_connect (priv->icon_entry->entry, "changed",
@@ -934,8 +990,10 @@ ephy_location_entry_set_completion (EphyLocationEntry *le,
 	gtk_entry_completion_set_model (completion, sort_model);
 	g_object_unref (sort_model);
 	gtk_entry_completion_set_match_func (completion, completion_func, le, NULL);
-	g_signal_connect (completion, "match_selected",
+	g_signal_connect (completion, "match-selected",
 			  G_CALLBACK (match_selected_cb), le);
+	g_signal_connect_after (completion, "action-activated",
+				G_CALLBACK (action_activated_after_cb), le);
 
 	cell = gtk_cell_renderer_text_new ();
 	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (completion),
@@ -1026,8 +1084,9 @@ ephy_location_entry_get_location (EphyLocationEntry *entry)
 	return gtk_entry_get_text (GTK_ENTRY (priv->icon_entry->entry));
 }
 
-gboolean
-ephy_location_entry_reset (EphyLocationEntry *entry)
+static gboolean
+ephy_location_entry_reset_internal (EphyLocationEntry *entry,
+				    gboolean notify)
 {
 	EphyLocationEntryPrivate *priv = entry->priv;
 	const char *text, *old_text;
@@ -1044,9 +1103,20 @@ ephy_location_entry_reset (EphyLocationEntry *entry)
 	ephy_location_entry_set_location (entry, text, NULL);
 	g_free (url);
 
+	if (notify)
+	{
+		g_signal_emit (entry, signals[USER_CHANGED], 0);
+	}
+
 	return retval;
 }
 
+gboolean
+ephy_location_entry_reset (EphyLocationEntry *entry)
+{
+	return ephy_location_entry_reset_internal (entry, FALSE);
+}
+
 void
 ephy_location_entry_activate (EphyLocationEntry *entry)
 {
