@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: prefs-dialog.c,v 1.125 2006/05/10 18:07:03 chpe Exp $
+ *  $Id: prefs-dialog.c,v 1.126 2006/07/21 19:57:05 chpe Exp $
  */
 
 #include "config.h"
@@ -138,6 +138,7 @@ enum
 	ALLOW_JAVA_PROP,
 	ALLOW_JS_PROP,
 	ACCEPT_COOKIES_PROP,
+	REMEMBER_PASSWORDS_PROP,
 	DISK_CACHE_PROP,
 	CLEAR_CACHE_BUTTON_PROP,
 
@@ -182,6 +183,7 @@ EphyDialogProperty properties [] =
 	{ "enable_java_checkbutton",		CONF_SECURITY_JAVA_ENABLED,	  PT_AUTOAPPLY, 0 },
 	{ "enable_javascript_checkbutton",	CONF_SECURITY_JAVASCRIPT_ENABLED, PT_AUTOAPPLY, 0 },
 	{ "cookies_radiobutton",		CONF_SECURITY_COOKIES_ACCEPT,	  PT_AUTOAPPLY, G_TYPE_STRING },
+	{ "remember_passwords_checkbutton",	CONF_PRIVACY_REMEMBER_PASSWORDS,  PT_AUTOAPPLY, 0 },
 	{ "disk_cache_spin",			CONF_NETWORK_CACHE_SIZE,	  PT_AUTOAPPLY, 0 },
 	{ "clear_cache_button",			NULL,				  PT_NORMAL,	0 },
 
